@@ -40,9 +40,9 @@
 namespace muFFT {
   namespace version {
 
-    constexpr bool git_dirty{false};
-    constexpr char git_describe[]{"0.9.0"};
-    constexpr char git_hash[]{"9561dcef9b64dfc4d85faeff40016e264c031001"};
+    constexpr bool git_dirty{true};
+    constexpr char git_describe[]{"0.9.2-dirty"};
+    constexpr char git_hash[]{"4ac0a714bdf614d06ed3af938a9e9060cef29dc7"};
 
     //------------------------------------------------------------------------//
     std::string info() {
