@@ -295,7 +295,7 @@ namespace muGrid {
         this->eigen_vec() = other.eigen_vec();
       } else {
         raw_mem_ops::strided_copy(this->get_shape(IterUnit::Pixel),
-                                  my_strides, other_strides, other.data(),
+                                  other_strides, my_strides, other.data(),
                                   this->data_ptr);
       }
       break;
